@@ -1,3 +1,7 @@
+"""
+This submodule contains the core atom_access functionality
+"""
+
 import numpy as np
 import xyz_py.atomic as atomic
 import numpy.linalg as la
@@ -131,7 +135,8 @@ def cluster_rays(rays, zcw_density):
         0.08132305,
         0.06399453,
         0.05033967,
-        0.03958930
+        0.03958930,
+        0.03112650
     ]
 
     clstr = AgglomerativeClustering(
@@ -255,10 +260,10 @@ def neighbours(rays, n):
 
     Parameters
     ----------
-    rays : np.array
-        rays as cartesian vectors, indended to be entire set of ZCW rays
+    rays : list
+        List of atom_access.objects.rays generated using ZCW algorithm
     n : int
-        nth nearest neighbour
+        Index of requested (nth) nearest neighbour
 
     Returns
     -------
